// Variables
$primary-color: #3498db;
$padding: 16px;

// Mixin for rounded corners
@mixin rounded-corners($radius) {
  border-radius: $radius;
}

// Styles
body {
  font-family: Arial, sans-serif;
  background-color: #f4f4f4;
}

header {
  background-color: $primary-color;
  color: white;
  padding: $padding;

  h1 {
    font-size: 2em;
    margin: 0;
  }
}

.button {
  background-color: $primary-color;
  color: white;
  padding: $padding;
  text-align: center;
  @include rounded-corners(5px);

  &:hover {
    background-color: darken($primary-color, 10%);
  }
}
