body {
  font-family: Arial, sans-serif;
  background-color: #f4f4f4;
}

header {
  background-color: #3498db;
  color: white;
  padding: 16px;
}
header h1 {
  font-size: 2em;
  margin: 0;
}

.button {
  background-color: #3498db;
  color: white;
  padding: 16px;
  text-align: center;
  border-radius: 5px;
}
.button:hover {
  background-color: rgb(33.13808, 125.18828, 186.86192);
}
